@@ -10,7 +10,7 @@ from .base import log_info
 
 __title__ = 'tld.tests.test_commands'
 __author__ = 'Artur Barseghyan'
-__copyright__ = '2013-2018 Artur Barseghyan'
+__copyright__ = '2013-2019 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('TestCommands',)
 
@@ -26,7 +26,7 @@ class TestCommands(unittest.TestCase):
     @log_info
     def test_1_update_tld_names_command(self):
         """Test updating the tld names (re-fetch mozilla source)."""
-        res = subprocess.check_output(shlex.split("update-tld-names")).strip()
+        res = subprocess.check_output(shlex.split("update-tld-names-2")).strip()
         self.assertEqual(res, b'True')
         return res
 
